==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/github/GithubWorkflowOptions.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) Options for `GithubWorkflow`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.767Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.GithubWorkflowOptions")
@software.amazon.jsii.Jsii.Proxy(GithubWorkflowOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface GithubWorkflowOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Concurrency ensures that only a single job or workflow using the same concurrency group will run at a time.
     * <p>
     * Currently in beta.
     * <p>
     * Default: - disabled
     * <p>
     * @see https://docs.github.com/en/actions/learn-github-actions/workflow-syntax-for-github-actions#concurrency
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getConcurrency() {
        return null;
    }

    /**
     * (experimental) Force the creation of the workflow even if `workflows` is disabled in `GitHub`.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getForce() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link GithubWorkflowOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link GithubWorkflowOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<GithubWorkflowOptions> {
        java.lang.String concurrency;
        java.lang.Boolean force;

        /**
         * Sets the value of {@link GithubWorkflowOptions#getConcurrency}
         * @param concurrency Concurrency ensures that only a single job or workflow using the same concurrency group will run at a time.
         *                    Currently in beta.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder concurrency(java.lang.String concurrency) {
            this.concurrency = concurrency;
            return this;
        }

        /**
         * Sets the value of {@link GithubWorkflowOptions#getForce}
         * @param force Force the creation of the workflow even if `workflows` is disabled in `GitHub`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder force(java.lang.Boolean force) {
            this.force = force;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GithubWorkflowOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public GithubWorkflowOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link GithubWorkflowOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GithubWorkflowOptions {
        private final java.lang.String concurrency;
        private final java.lang.Boolean force;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.concurrency = software.amazon.jsii.Kernel.get(this, "concurrency", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.force = software.amazon.jsii.Kernel.get(this, "force", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.concurrency = builder.concurrency;
            this.force = builder.force;
        }

        @Override
        public final java.lang.String getConcurrency() {
            return this.concurrency;
        }

        @Override
        public final java.lang.Boolean getForce() {
            return this.force;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getConcurrency() != null) {
                data.set("concurrency", om.valueToTree(this.getConcurrency()));
            }
            if (this.getForce() != null) {
                data.set("force", om.valueToTree(this.getForce()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.GithubWorkflowOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GithubWorkflowOptions.Jsii$Proxy that = (GithubWorkflowOptions.Jsii$Proxy) o;

            if (this.concurrency != null ? !this.concurrency.equals(that.concurrency) : that.concurrency != null) return false;
            return this.force != null ? this.force.equals(that.force) : that.force == null;
        }

        @Override
        public final int hashCode() {
            int result = this.concurrency != null ? this.concurrency.hashCode() : 0;
            result = 31 * result + (this.force != null ? this.force.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/github/GithubWorkflowOptions.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) Options for <code>GithubWorkflow</code>.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.432Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.GithubWorkflowOptions")
@software.amazon.jsii.Jsii.Proxy(GithubWorkflowOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface GithubWorkflowOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Concurrency ensures that only a single job or workflow using the same concurrency group will run at a time.
     * <p>
     * Currently in beta.
     * <p>
     * Default: - disabled
     * <p>
     * @see <a href="https://docs.github.com/en/actions/learn-github-actions/workflow-syntax-for-github-actions#concurrency">https://docs.github.com/en/actions/learn-github-actions/workflow-syntax-for-github-actions#concurrency</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getConcurrency() {
        return null;
    }

    /**
     * (experimental) Force the creation of the workflow even if <code>workflows</code> is disabled in <code>GitHub</code>.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getForce() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link GithubWorkflowOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link GithubWorkflowOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<GithubWorkflowOptions> {
        java.lang.String concurrency;
        java.lang.Boolean force;

        /**
         * Sets the value of {@link GithubWorkflowOptions#getConcurrency}
         * @param concurrency Concurrency ensures that only a single job or workflow using the same concurrency group will run at a time.
         *                    Currently in beta.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder concurrency(java.lang.String concurrency) {
            this.concurrency = concurrency;
            return this;
        }

        /**
         * Sets the value of {@link GithubWorkflowOptions#getForce}
         * @param force Force the creation of the workflow even if <code>workflows</code> is disabled in <code>GitHub</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder force(java.lang.Boolean force) {
            this.force = force;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GithubWorkflowOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public GithubWorkflowOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link GithubWorkflowOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GithubWorkflowOptions {
        private final java.lang.String concurrency;
        private final java.lang.Boolean force;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.concurrency = software.amazon.jsii.Kernel.get(this, "concurrency", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.force = software.amazon.jsii.Kernel.get(this, "force", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.concurrency = builder.concurrency;
            this.force = builder.force;
        }

        @Override
        public final java.lang.String getConcurrency() {
            return this.concurrency;
        }

        @Override
        public final java.lang.Boolean getForce() {
            return this.force;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getConcurrency() != null) {
                data.set("concurrency", om.valueToTree(this.getConcurrency()));
            }
            if (this.getForce() != null) {
                data.set("force", om.valueToTree(this.getForce()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.GithubWorkflowOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GithubWorkflowOptions.Jsii$Proxy that = (GithubWorkflowOptions.Jsii$Proxy) o;

            if (this.concurrency != null ? !this.concurrency.equals(that.concurrency) : that.concurrency != null) return false;
            return this.force != null ? this.force.equals(that.force) : that.force == null;
        }

        @Override
        public final int hashCode() {
            int result = this.concurrency != null ? this.concurrency.hashCode() : 0;
            result = 31 * result + (this.force != null ? this.force.hashCode() : 0);
            return result;
        }
    }
}
